@@ -268,6 +268,20 @@ register_setting(
     default="",
 )
 
+register_setting(
+    name="HOST_THEMES",
+    description=_("A sequence mapping host names to themes, allowing "
+                  "different templates to be served per HTTP hosts "
+                  "Each item in the sequence is a two item sequence, "
+                  "containing a host such as ``othersite.example.com``, and "
+                  "the name of an importable Python package for the theme. "
+                  "If the host is matched for a request, the templates "
+                  "directory inside the theme package will be first searched "
+                  "when loading templates."),
+    editable=False,
+    default=(),
+)
+
 register_setting(
     name="MAX_PAGING_LINKS",
     label=_("Max paging links"),
