@@ -6,6 +6,7 @@ from django.middleware.cache import FetchFromCacheMiddleware
 
 from mezzanine.conf import settings
 from mezzanine.utils.device import device_from_request, templates_for_device
+from mezzanine.utils.sites import templates_for_host
 
 
 class AdminLoginInterfaceSelectorMiddleware(object):
@@ -47,6 +48,17 @@ class TemplateForDeviceMiddleware(object):
         return response
 
 
+class TemplateForHostMiddleware(object):
+
+    def process_template_response(self, request, response):
+        """
+        Inserts host-specific templates to the template list.
+        """
+        templates = templates_for_host(request, response.template_name)
+        response.template_name = templates
+        return response
+
+
 class DeviceAwareCacheMiddleware(object):
     """
     Mixin for device-aware cache middleware that provides the method for
