@@ -5,7 +5,6 @@ from django.utils.safestring import mark_safe
 from django.utils.translation import ugettext_lazy as _
 
 from mezzanine.generic.models import Keyword, ThreadedComment, RATING_RANGE
-from mezzanine.utils.urls import content_media_urls
 
 
 class KeywordsWidget(forms.MultiWidget):
@@ -26,8 +25,8 @@ class KeywordsWidget(forms.MultiWidget):
     """
 
     class Media:
-        js = content_media_urls("js/jquery-1.4.4.min.js",
-                                "js/keywords_field.js")
+        js = ("mezzanine/js/jquery-1.4.4.min.js",
+              "mezzanine/js/admin/keywords_field.js",)
 
     def __init__(self, attrs=None):
         """
@@ -82,6 +81,24 @@ class ThreadedCommentForm(CommentForm):
     url = forms.URLField(label=_("Website"), help_text=_("optional"),
                          required=False)
 
+    # These are used to get/set prepopulated fields via cookies.
+    cookie_fields = ("name", "email", "url")
+    cookie_prefix = "mezzanine-comment-"
+
+    def __init__(self, request, *args, **kwargs):
+        kwargs.setdefault("initial", {})
+        user = request.user
+        for field in ThreadedCommentForm.cookie_fields:
+            cookie_name = ThreadedCommentForm.cookie_prefix + field
+            value = request.COOKIES.get(cookie_name, "")
+            if not value and user.is_authenticated():
+                if field == "name":
+                    value = user.get_full_name() or user.username
+                elif field == "email":
+                    value = user.email
+            kwargs["initial"][field] = value
+        super(ThreadedCommentForm, self).__init__(*args, **kwargs)
+
     def get_comment_model(self):
         """
         Use the custom comment model instead of the built-in one.
@@ -94,5 +111,5 @@ class RatingForm(CommentSecurityForm):
     Form for a rating. Subclasses ``CommentSecurityForm`` to make use
     of its easy setup for generic relations.
     """
-    value = forms.ChoiceField(label=_("Rating"), widget=forms.RadioSelect,
+    value = forms.ChoiceField(label="", widget=forms.RadioSelect,
                               choices=zip(RATING_RANGE, RATING_RANGE))
